pub struct PdfFile {
pub header: PdfHeader,
pub xref: XrefTable,
pub trailer: PdfDict,
/* private fields */
}Fields
header: PdfHeaderxref: XrefTabletrailer: PdfDictImplementations
Sourceimpl PdfFile
impl PdfFile
pub fn parse(data: impl Into<Arc<[u8]>>) -> Result<Self>
pub fn parse_with_limits( data: impl Into<Arc<[u8]>>, limits: ParseLimits, ) -> Result<Self>
pub fn resolve(&self, id: ObjectId) -> Result<PdfObject>
Sourcepub fn resolve_stream_data(&self, id: ObjectId) -> Result<Vec<u8>>
pub fn resolve_stream_data(&self, id: ObjectId) -> Result<Vec<u8>>
Resolve a stream object and decode its data through the filter pipeline.
/Filter and /DecodeParms may be indirect references (or arrays
containing them); resolve those before handing the dict to the filter
layer, which has no access to the file.
pub fn data(&self) -> &[u8] ⓘ